@@ -81,6 +81,10 @@ class RussianProfileUpdateContract(ProfileUpdateContract):
     snils = serializers.CharField(max_length=64)
 
 
+class RussianProfileUpdateAddressContract(Contract):
+    address = serializers.CharField(max_length=256)
+
+
 class RussianProfileCreateContract(ProfileCreateContract):
     passport_serial = serializers.CharField(max_length=4)
     passport_number = serializers.CharField(max_length=6)
@@ -157,6 +161,12 @@ class RussianProfileID(ID):
     _view_set = 'russian_profile'
 
 
+class RussianProfileUpdateAddressID(ID):
+    _service = SERVICE
+    _app = 'profiles'
+    _view_set = 'russian_profile_update_address'
+
+
 class UserProfileID(ID):
     _service = SERVICE
     _app = 'profiles'
@@ -244,6 +254,11 @@ class RussianProfileObjectPoint(RetrievePointMixin, UpdatePointMixin, ContractOb
     _update_contract = RussianProfileUpdateContract
 
 
+class RussianProfileObjectUpdateAddressPoint(UpdatePointMixin, ContractObjectPoint):
+    _point_id = RussianProfileUpdateAddressID()
+    _update_contract = RussianProfileUpdateAddressContract
+
+
 class ProfileObjectPoint(RetrievePointMixin, ContractObjectPoint):
     _point_id = ProfileID()
     _read_contract = ProfileReadContract
